==> qpid-cpp_0.12.orig.tar.gz: qpidc-0.12/src/qpid/broker/DtxAck.h <==
/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */
#ifndef _DtxAck_
#define _DtxAck_

#include <algorithm>
#include <functional>
#include <list>
#include "qpid/framing/SequenceSet.h"
#include "qpid/broker/DeliveryRecord.h"
#include "qpid/broker/TxOp.h"

namespace qpid {
    namespace broker {
        class DtxAck : public TxOp{
            DeliveryRecords pending;

        public:
            DtxAck(const framing::SequenceSet& acked, DeliveryRecords& unacked);
            virtual bool prepare(TransactionContext* ctxt) throw();
            virtual void commit() throw();
            virtual void rollback() throw();
            virtual ~DtxAck(){}
            virtual void accept(TxOpConstVisitor& visitor) const { visitor(*this); }
        };
    }
}


#endif

==> qpid-cpp_0.16.orig.tar.gz: qpidc-0.16/src/qpid/broker/DtxAck.h <==
#ifndef QPID_BROKER_DTXACK_H
#define QPID_BROKER_DTXACK_H

/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */
#include <algorithm>
#include <functional>
#include <list>
#include "qpid/framing/SequenceSet.h"
#include "qpid/broker/DeliveryRecord.h"
#include "qpid/broker/TxOp.h"

namespace qpid {
namespace broker {
class DtxAck : public TxOp{
    DeliveryRecords pending;

  public:
    DtxAck(const framing::SequenceSet& acked, DeliveryRecords& unacked);
    DtxAck(DeliveryRecords& unacked);
    virtual bool prepare(TransactionContext* ctxt) throw();
    virtual void commit() throw();
    virtual void rollback() throw();
    virtual ~DtxAck(){}
    virtual void accept(TxOpConstVisitor& visitor) const { visitor(*this); }
    const DeliveryRecords& getPending() const { return pending; }
};

}} // qpid::broker

#endif  /*!QPID_BROKER_DTXACK_H*/
